unit ufScriptForm;

{
This is the user interface unit.  All of the ActiveScript initialization,
execution, and clean up is handled in a singe ButtonClick handler.  This,
of course, is a bad way of implimenting ActiveScript, but for the
purposes of the demo, it's a great way of showing all the necessary steps
involved in a straight forward way.
}

interface

uses
  Windows, Messages, Classes, Controls, Forms, Dialogs, StdCtrls, ExtCtrls, Sysutils,
  ComCtrls, OleCtrls;


type
  TfScriptForm = class(TForm)
    Panel1: TPanel;
    panelTopRight: TPanel;
    panelTopLeft: TPanel;
    btnGo: TButton;
    panelCode: TPanel;
    rbJava: TRadioButton;
    rbVB: TRadioButton;
    pcCode: TPageControl;
    tsJ: TTabSheet;
    tsVB: TTabSheet;
    mVBCode: TMemo;
    mJCode: TMemo;
    procedure btnGoClick(Sender: TObject);
    procedure FormResize(Sender: TObject);
    procedure rbJavaClick(Sender: TObject);
    procedure rbVBClick(Sender: TObject);
  private
    { Private declarations }
  public
    { Public declarations }
  end;

var
  fScriptForm: TfScriptForm;

implementation

{$R *.DFM}

uses ComObj, uCoolObject, ActiveX, AXScript, AXScriptHelp, AXScriptDemo_TLB, uScriptSite;

procedure TfScriptForm.btnGoClick(Sender: TObject);
var
  ActiveScriptParse: IActiveScriptParse;
  ActiveScript: IActiveScript;
  Code: WideString;
  Result: OleVariant;
  ExcepInfo: TExcepInfo;
  ScriptSite:TScriptSiteWindow;
  Cool:IUnknown; //this is the automation object exposed to the script
  engineID:TCLSID;

begin
  if (rbVb.Checked) then begin
    engineID:=Clsid_VBScript;
    Code:=mVBCode.Text;
  end else begin
    engineID:=Clsid_JScript;
    Code:=mJCode.Text;
  end;

  if (Code='') then exit;
  Result:=unassigned;

  ScriptSite:=TScriptSiteWindow.Create;
  ScriptSite.WindowHandle:=Handle;

  CreateScriptEngine(EngineID, ActiveScript, ActiveScriptParse, ScriptSite);
  //if not Assigned(ActiveScriptParse) then
    //raise Exception.Create('IActiveScriptParse must be supported for scripting');

  try
    if SUCCEEDED(ActiveScriptParse.InitNew) then begin
      //create a TCoolObject and assigne it to the Cool interface
      Cool:=TCoolObject.Create;

      //add Cool to our private list of globals in the ScriptSite
      ScriptSite.AddGlobal('Cool', Cool);

      //now, add cool to the script's namespace.  When the engine needs to get
      //information about what "cool" means, it'll call ScriptSite's GetItemInfo.
      //since we added Cool to ScriptSite's global list, it'll be able to look
      //up any information (Either the IUnknown or ITypeInfo interfaces) that
      //the engine looks for.
      ActiveScript.AddNamedItem('Cool',
                                   SCRIPTITEM_ISVISIBLE       //Allows the script to "see" the Cool object
                                or SCRIPTITEM_GLOBALMEMBERS   //Allows the sript to use Cool's members without referencing Cool directly.
                                or SCRIPTITEM_ISSOURCE        //Tells the script engine that Cool generates events that it should hook up to.
                                or SCRIPTITEM_ISPERSISTENT    //Keep Cool around of the script is "persisted" (or saved) directly by the engine.
                                //or SCRIPTITEM_CODEONLY      //Synonymous to creating a class instead of an instance of a class.  Using this "feature" gives me lots of access errors.
                                //or SCRIPTITEM_NOCODE        //Sorry, I don't quite understand the use of this one.
                                );

      //This next call returns E_NOTIMPL for both MS Script engines.
      //ActiveScript.AddTypeLib(LIBID_AXScriptDemo, 1, 0, 0);

      //Go!
      OleCheck(ActiveScript.SetScriptState(SCRIPTSTATE_CONNECTED));
      ActiveScriptParse.ParseScriptText(POleStr(Code),nil,nil,nil,0,0,SCRIPTTEXT_ISPERSISTENT or SCRIPTTEXT_ISVISIBLE,Result,ExcepInfo);
    end; //if InitNew
  except
    ShowMessage('Exception');
  end;

  //The compiler will generate code to automatically call _Release on ActiveScript
  //and ActiveScriptParse (and also Cool) when the variables go out of scope.
end; //btnGoClick


//And just to make it look nice...
procedure TfScriptForm.FormResize(Sender: TObject);
const Margin=4;
begin
  panelTopleft.Width:=clientWidth div 2;
  btnGo.Top:=margin;
  btnGo.Left:=margin;
  btnGo.Width:=btnGo.Parent.Width - (2*Margin);
  btnGo.Height:=btnGo.Parent.Height - (2*Margin);

  mVBCode.Top:=Margin;
  mVBCode.Left:=Margin;
  mVBCode.Width:=mVBCode.Parent.Width - (2*Margin);
  mVBCode.Height:=mVBCode.Parent.Height - (2*Margin);

  mJCode.Top:=Margin;
  mJCode.Left:=Margin;
  mJCode.Width:=mJCode.Parent.Width - (2*Margin);
  mJCode.Height:=mJCode.Parent.Height - (2*Margin);


  rbJava.Top:=(rbJava.Parent.Height div 2) - (rbJava.Height div 2) + 1;
  rbVB.Top:=rbJava.Top;
  rbJava.Width:=(rbJava.Parent.Width - (3*Margin)) div 2;
  rbVb.Width:=rbJava.Width;
  rbJava.Left:=Margin;
  rbVb.Left:=rbJava.left+rbJava.Width+Margin;
end;



procedure TfScriptForm.rbJavaClick(Sender: TObject);
begin
  pcCode.ActivePage:=tsJ;
end;

procedure TfScriptForm.rbVBClick(Sender: TObject);
begin
  pcCode.ActivePage:=tsVB;
end;



initialization
  OleInitialize(nil);  //gotta call this...
finalization
  OleUnInitialize;  //gotta call this, too
end.

